@@ -115,15 +115,15 @@ class UserMeta(models.Model):
             self.save()
         return self.organization
 
-    def google_authenticated(self):
+    def google_authenticated(self) -> bool:
         try:
             self.user.social_auth.get(provider='google-oauth2')
             return True
         except UserSocialAuth.DoesNotExist:
             return False
 
-    def is_organization_owner(self):
-        return self.organization.owner == self.user
+    def is_organization_owner(self) -> bool:
+        return self.organization.owner == self.user if self.organization else False
 
     def _user_meta(self, organization=None):
         return UserMeta.objects.get_or_create(user=self, defaults={'organization': organization})[0]
@@ -388,6 +388,8 @@ class PartRevision(models.Model):
     weight = models.DecimalField(max_digits=7, decimal_places=3, default=None, null=True, blank=True)
     temperature_rating_units = models.CharField(max_length=5, default=None, null=True, blank=True, choices=TEMPERATURE_UNITS)
     temperature_rating = models.DecimalField(max_digits=7, decimal_places=3, default=None, null=True, blank=True)
+    temperature_rating_range_max = models.DecimalField(max_digits=7, decimal_places=3, default=None, null=True, blank=True)
+    temperature_rating_range_min = models.DecimalField(max_digits=7, decimal_places=3, default=None, null=True, blank=True)
     wavelength_units = models.CharField(max_length=5, default=None, null=True, blank=True, choices=WAVELENGTH_UNITS)
     wavelength = models.DecimalField(max_digits=7, decimal_places=3, default=None, null=True, blank=True)
     frequency_units = models.CharField(max_length=5, default=None, null=True, blank=True, choices=FREQUENCY_UNITS)
